TRANSCAN.DOC

37.2 KB 9831f71b70771702…
ANSI art: TRANSCAN.DOC
B


     1/3/92                      TRANSCAN v2.21                      Page 1
     ----------------------------------------------------------------------

      
      
      
       ARC  ARJ  DWC  HYP  ICE  LZH  PAK  SDN  ZIP  ZOO  ARC  ARJ  DWC
       ICE  LZH  PAK  SDN  ZIP  ZOO  ARC  ARJ  DWC  HYP  ICE  LZH  PAK
       ZIP  ZOO  *********  ********     *****    ***    ***  ARC  ARJ
       ARC  ARJ     ***     ***  ***    *** ***   *****  ***  HYP  ICE
       DWC  HYP     ***     ***  **    ***   ***  *** ** ***  PAK  SDN
       ICE  LZH     ***     ********   *********  ***  *****  ZOO  ARC
       PAK  SDN     ***     ***   ***  ***   ***  ***   ****  DWC  HYP
       ZIP  ZOO     ***     ***   ***  ***   ***  ***    ***  LZH  PAK
       ARC  ARJ  DWC  HYP  ICE  LZH  PAK  SDN  ZIP  ZOO  ARC  ARJ  DWC
       ICE  LZH  PAK  SDN  ZIP  ZOO  ARC  ARJ  DWC  HYP  ICE  LZH  PAK
      
     virus  virus  virus  virus  virus  virus  virus  virus  virus  virus
     virus  virus  virus  virus  virus  virus  virus  virus  virus  virus
     virus     ******      *******       *****  **   **  *****      virus
     virus   ***         ***     **    **    ** **   ** **   **     virus
     virus     ***      ***           **       ***   ***      **    virus
     virus       ***    **           **         **   **        **   virus
     virus         ***  ***           **       ***   **        **   virus
     virus        ***    ***    **      **   ** **   **        **   virus
     virus   ******        *******        ****  **  ***        ***  virus
     virus  virus  virus  virus  virus  virus  virus  virus  virus  virus
     virus  virus  virus  virus  virus  virus  virus  virus  virus  virus
      
                   TRANSCAN (c) 1991-1992 by Craig E. Dunstan
      
      




























     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                      Page 2
     ----------------------------------------------------------------------

      
      
     Description:

          TranScan has been designed to work with Wildcat v3+.  TranScan
          may be run from your SCANFILE.BAT file with the following command
          line:

               TRANSCAN %1

          It detects the presence of an online caller by looking for
          DOOR.SYS in the proper NodeWork directory determined by the
          Environment variable NODEID.  It autodetects which COM port is
          active for this node and displays the TranScan screen to the
          online caller.  TranScan then UnCompresses the upload whether it
          is an ARC, ARJ, DWC, HYP, ICE, LZH, PAK, SDN, ZIP, or ZOO file
          (ten types in all).  TranScan then Scans those files for viruses
          using ViruScan by McAfee & Associates.  If a virus is found
          TranScan creates SCANFILE.BAD in the NodeWork directory for later
          use by Wildcat.  If the file is an ARJ or ZIP file TranScan will
          add the text found in TRANSCAN.CMT as the file comment.  Since
          adding a file comment slightly increases the size of the file,
          TranScan will update the Wildcat Database to reflect this new
          size. (Note Writing to the COM port is only available in COM
          REGISTERED versions).

          TranScan also writes the file path and name to TRANSCAN.LST.  You
          can then run TranScan durring your daily maintenance to convert
          the day's uploads to your compression method of choice.  All this
          can be accomplished with one simple command line like the one
          below:

               TRANSCAN -F -CARJ -G

          This command line would process all the files in the TRANSCAN.LST
          file converting them to *.ARJ files.  The -G switch tells
          tranScan to use GIFLite to even compress GIF files.  The file
          Name and Size is automatically updated in your Wildcat database,
          too.


















     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                      Page 3
     ----------------------------------------------------------------------

     Special Features:

          o    TranScan can process one file, a directory of files, or a
               list of files contained in a text file. 

          o    TranScan processes Imbedded Compressed files to any level!

          o    TranScan's registered COM version supports full color ANSI
               and non-ANSI displays (autodetected) to the online caller
               durring processing.  It supports Ports 1-8, and baud rates
               up to 115,000.   

          o    TranScan's registered NETWORK version supports full Network
               support including file locking for ALL networks supported by
               Wildcat!  

          o    TranScan can convert the files to your compression method of
               choice right away or if you choose you can have it only Scan
               them for viruses and write the names to a list file for
               later processing.  This is useful if you want the files
               Scanned after upload but prefer to have them Compressed
               during daily maintenance. 

          o    TranScan supports compression of GIF files using GIFLite.
               It will even support compression of GIF files Imbedded in
               other compressed files. 

          o    TranScan AUTOMATICALLY updates the file info for Wildcat
               3.0.  This includes fileSize, fileDate, fileName, and if a
               virus is detected the Failed Scan flag. 

          o    TranScan searches your Path for the external files it needs
               and then only supports those types of compressions it finds
               support files for (For example: If you do not have ARJ.EXE
               located in your path, TranScan will not be able to support
               *.ARJ files). 

          o    TranScan also deletes files from the archive if the filename
               is in a TextFile called TRANSCAN.DEL.   

          o    Files may be date stamped using the date of the Youngest
               file or Oldest File in the compressed file, the Current
               system date, or Keep the Original file date. 

          o    TranScan has an optional SelectiveScan feature that causes
               it to only scan new files added to a directory.  This allows
               SysOps running Wildcat v1+ or v2+ to scan their upload
               directories after every call without reScanning every file. 

          o    TranScan has a log features that lets you review TranScan's
               processing at a later time.  It includes information like
               the following:
                
               -    TranScan Version, Date, and Time of Processing.



     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                      Page 4
     ----------------------------------------------------------------------

               -    Age of file in DAYS (based on time stamp).
               -    Name of virus detected by SCAN.EXE if any.
               -    Reason file could not be UnCompressed if any.
               -    Amount of bytes saved by new Compression.
               -    Total time taken by External Programs & TranScan.
               -    Wildcat Updated and if not why.

          o    TranScan uses ZC200.EXE to add your Zip Comments Auto-
               matically. TranScan also adds Arj Comments Automatically.
               Just put your ARJ or ZIP comment file in a file named
               TRANSCAN.CMT and locate this file in the same directory as
               TRANSCAN.EXE. 

          o    TranScan supports Encryption Authenticity verification in
               ZIP files.  It ads '-AV' to listing if you have a registered
               version of PkZip.Exe. 

          o    Configuration File attached to TranScan.Exe file so you
               don't need to keep track of another file. 

          o    A built in MINUTE timer lets you set TranScan to covert your
               files from one format to another for so many MINUTES.  The
               conversion will stop after that time has passed.  In the
               conversion (from ZIP to ARJ for example) TranScan updates
               your WC 3.0 database to reflect the new fileSize, fileDate
               and name. 

     Command Line: 

          TRANSCAN [fileName] [-Switch<instruction>] 

     Operation: 

          Switches must be preceded by a hyphen '-' or back-slash '/'.
          Switches include: 

     -C<method>               ReCompress all files after Scanning using
                              this method.  Valid methods include:  ARC,
                              ARJ, DWC, HYP, ICE, LZH, PAK, ZIP, ZOO, and
                              NONE.  If NONE is selected TranScan will
                              write a list of files scanned to TRANSCAN.LST
                              for later processing (Default is NONE). 

     -D<fullPath>             Process this entire directory described by
                              fullPath (TranScan defaults to the current
                              directory if no file is on the command line.
                              In this case the -D switch is not necessary). 

     -F                       Process the files listed in TRANSCAN.LST.

     -F<filePathAndName>      Process the files listed in this text file
                              (include full path and name). 





     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                      Page 5
     ----------------------------------------------------------------------


     -G                       Use GIFLite to compress *.GIF files, even
                              nested inside other Compressed files (NOTE:
                              GIFLITE really compresses but it is
                              incredibly slow.  I would never use the -G
                              switch in the SCANFILE.BAT set-up). 

     -J<junkFilePathAndName>  This is the Text file containing the list of
                              filenames you do not want included with the
                              file as it is ReCompressed.  This is helpful
                              to delete unwanted extra files like
                              COMMAND.COM, PKUNZIP.EXE, BBS.AD, etc.
                              (TranScan will look for TRANSCAN.DEL in the
                              same directory as TRANSCAN.EXE if this switch
                              is not used.  If it cannot find TRANSCAN.DEL
                              no problem. 

     -L<logPathAndName>       This switch defines which file you want your
                              Log entries written to.  You may want them
                              printed to your ACTIVITY.LOG for example
                              (TranScan defaults to TranScan.Log and places
                              this in the same directory as TranScan.Exe). 

     -M<minutes>              This switch tells TranScan to only process
                              for so many minutes.  This is helpful if you
                              want to convert your files from any
                              compression type to another during daily
                              maintenance.  This works great if you have a
                              lot of GIF files.  You can GIFLite them for
                              say 60 minutes per day until the process is
                              finished. 

     -N                       This displays the Programs Needed by TranScan
                              for full operation and it checks those
                              programs it has found in your Path. (must be
                              the only switch). 

     -S                       This SelectiveScan switch instructs TranScan
                              to look for the file TRANSCAN.DID in the
                              directory it is to process.  This file
                              contains a list of all the files in that
                              directory that TranScan has already
                              processed.  It will only process files it
                              does not find in the list and it adds all the
                              files it processes to the list. 

     -T<K|C|Y|O><W>           This TimeStamp switch instructs TranScan on
                              how to date the finished file.
                                 -TK for Keep Original File Date.
                                 -TC for Current System Date.
                                 -TY for Date of Youngest File in the file.
                                 -TO for Date of Oldest File in the file.
                              Put a "W" behind any one of these date
                              switches (-TKW, -TCW, -TYW, or -TOW) if you



     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                      Page 6
     ----------------------------------------------------------------------

                              want the date changed in the Wildcat
                              Database.  I would recommend careful
                              consideration of this because adding the "W"
                              basically eliminates the functionality of the
                              "[N]ew Files Since" command on the Wildcat
                              Files Menu.

     -X                       This switch tells TranScan to NOT re-compress
                              a file that is already compressed with the
                              method of choice.  (For example: if -cZIP -x
                              is selected TranScan will not Re-Zip ZIP
                              files. 

     -Z<filePathAndName>      This points to the Comment file you wish
                              added to all ZIPs and ARJs.  If this switch
                              is not used TranScan will add the contents of
                              TRANSCAN.CMT as the ZIP or ARJ comment if it
                              exists.  This file should be in the same
                              directory as TRANSCAN.EXE. 

     -!                       If you have a REGISTERED version of PKZIP you
                              can include this switch on the command line.
                              This switches Authenticity Verification ON
                              while PKZIP processes your files.  See the
                              Manual that comes with PKZIP for more
                              information. 

     -?                       Displays a simple Help Screen (must be the
                              only switch). 

     Exit Errorlevels: 

               10   DOS ERROR! Check Log File for Explanation!

               5    Error on Command Line!

               4    Error Detected during Compression!

               3    Error Detected during Virus Scan!

               2    Error Detected during UnCompression!

               1    VIRUS DETECTED!

               0    Program Terminated Normally! No Virus Detected!

     Other Programs Required by TranScan: 

          TranScan uses the SCAN.EXE program by McAfee Associates to test
          each file for viruses.  You should have SCAN.EXE in a directory
          pointed to by your PATH statement.  Be sure that you have the
          latest copy of SCAN.EXE because it keeps changing as new Viruses
          are detected. 




     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                      Page 7
     ----------------------------------------------------------------------


          TranScan also executes several programs to UnCompress and
          Compress files.  You should have the following programs in a
          directory pointed to by your PATH statement:

          PKZIP.EXE & PKUNZIP.EXE for processing *.ZIP files.
          LHA.EXE for processing *.LZH files.
          ICE.EXE for processing *.ICE files.
          PAK.EXE for processing *.PAK files.
          PKPAK.EXE & PKUNPAK.EXE for processing *.ARC files.
          ZOO.EXE for processing *.ZOO files.
          HYPER.EXE for processing *.HYP files.
          ARJ.EXE for processing *.ARJ files.
          GIFLITE.EXE for processing *.GIF files.

          TranScan will operate if you do not have one of these files, it
          will just not be able to UnCompress files with that extension or
          Compress them using that extension.

          TranScan also looks for ZC.EXE in the current path to add Zip-
          Comments to your Zip files.

     Example SCANFILE.BAT:

          This batch file is called after every upload in Wildcat v3.00 to
          provide virus checking.

          TRANSCAN %1
           
          It is necessary to add the following line in your Cat.Bat file:

          SET WCNODEID=1

          TranScan will erase SCANFILE.BAD if it exists and will create
          SCANFILE.BAD if any problems are detected with the Upload.
          Wildcat uses SCANFILE.BAD to set the "Failed Scan" switch in the
          file record.  If the file failed the scan Wildcat will not allow
          access to the file in any way.

          NOTE--NOTE--NOTE--NOTE--NOTE--NOTE--NOTE--NOTE--NOTE--NOTE--NOTE

          Please note this quote from the Wildcat 3.0 manual:

               "Note that for proper operation WILDCAT! expects the same
               filename to be returned after the virus scan that was sent
               to the SCANFILE.BAT.  Manipulations may be made in the scan
               process, but the filename must be unchanged."

          If you put -CZIP or -C<anything> on the command line you will
          violate this Wildcat rule!  So, I have written TranScan to
          default to -Cnone when processing a file from within the
          ScanFile.Bat process.  I will change this just as soon as Wildcat
          changes their policy.




     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                      Page 8
     ----------------------------------------------------------------------


     Example DAILY.BAT file for WC v3+ users to:

          TRANSCAN -F -G -Carj

          This tells TranScan to process all uploads previously scanned and
          convert them to the ARJ format.  It also tells TranScan to
          GIFLite any GIF files it finds.

          I run this between calls just before my mailer takes control.  In
          this way the board does not appear to be down for extended
          periods of time.

          I do not recommend using this from the POSTCALL.BAT file however
          since Wildcat writes DOOR.SYS before running POSTCALL.BAT.  This
          will cause TranScan to behave most unpredictably!

     Example CAT.BAT section for WC v1+ and v2+:

          CD\UPLOADS
          TRANSCAN -S
          rem       +------- SelectiveScan only NEW files

     Example AFTRMAIL.BAT section for checking INBOUND files:

          CD\MAIL\INBOUND
          TRANSCAN -CZIP -TC -X
          rem      ^^|^^ ^|^ ^|
          rem        |    |   +-- eXclude ReZIPping ZIP files
          rem        |    +-- TimeStamp file with Current Date
          rem        +-- Compress all files using ZIP

     Command Line Examples:

          TRANSCAN -Dc:\uploads\ -Lc:\wildcat\node1\activity.log -CNONE

          Process ALL files in C:\UPLOADS\ directory.  Write Log Entries to
          C:\WILDCAT\NODE1\ACTIVITY.LOG.  Do not ReCompress the file!
           

          TRANSCAN -Dc:\telix\downloads\ -Lc:\telix\scan.log -CLZH -TC

          Process ALL files in C:\TELIX\DOWNLOADS\ directory.  Write Log
          Entries to C:\TELIX\SCAN.LOG.  Change all files to LZH
          compression after Scanning. TimeStamp the files with the Current
          system date.

          TRANSCAN -F -CZIP -TO -! -X

          Process ALL files listed in the text file TRANSCAN.LST.  Change
          all files to ZIP compression after Scanning.  TimeStamp the files
          with the Original Compressed File Date.  Write Authenticity
          Verification to the files as they are ZIPped. eXclude processing
          of files that are already ZIPped (Note: if the -X switch is used



     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                      Page 9
     ----------------------------------------------------------------------

          with the -! switch your Authenticity Verification will NOT be
          stamped to files that are already in the ZIP format).
           

          CD \ZIP\A
          TRANSCAN

          Change to directory \ZIP\A and process ALL files in that
          directory.

          CD \GIFFILES\
          TRANSCAN -G -S -M35

          Change to directory containing my GIF files and GIFLite those
          that have not yet been processed for 35 minutes.

     Copyright:

          This program is distributed as SHAREWARE.  Under this concept you
          may use the SHAREWARE (UnRegistered) version for a reasonable
          period of time, which I consider to be 30 days, after which you
          must register your copy or discontinue usage all together.

     Warranty:

          This program is provided "as is" without any warranty of any
          kind.  The entire risk of using this program is assumed by you.
          I suggest you backup your files before using all programs to
          prevent unrecoverable damage.

     Registration:

          With registration you will receive access to download or File
          Request any further updates from THE COMPUTER POST at no extra
          cost.  Cost to register this program is only $5.  To register
          complete the attached registration form.

     Pricing structure of TranScan:

          o    The single user version of TranScan will continue to cost
               only $5 for registration. 

          o    Adding Com support will only cost an additional $5.

          o    Adding Network support for TranScan will only cost an
               additional $5. 

          o    NOTE: Com support and Network support should be through
               testing in a few weeks.  Let me know if you are interested
               in helping test this additional support to TranScan. 

     Distribution: 





     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                     Page 10
     ----------------------------------------------------------------------


          You are free, in fact encouraged, to distribute the SHAREWARE
          (UnRegistered) version of this program in the original archive in
          absolute original unmodified form.

     Files Included in Archive:

          TRANSCAN.EXE   This is the executable file.

          TRANSCAN.DOC   This document file.

          PROGRAM.LST    List of Programs by Craig E. Dunstan.

          TSQUICK.DOC    This is a "Quick Start-Up" Document.

     Acknowledgements: 

          o    Wildcat! (tm)  (c) Mustang Software, Bakersfield, CA.

          o    These programs were written using Turbo Pascal 5.5 from
               Boreland International, Scotts Valley, CA. 

          o    These programs were written using B-Tree Filer and AsyncPro
               from Turbo Power Software, (c) 1989-1991, Scotts Valley, CA. 

          o    Viruscan (c) 1989-1991 by McAfee Associates.

          o    ZC (c) by Jeff Garzik.

          o    PkPak, PkUnPak, PkZip (tm), and PkUnZip (tm) (c) 1986-1989
               by Phillip W. Katz, PKWARE Inc. 

          o    LHa, LHarc and LHice (c) 1988-1989 by Haruyasu Yoshisaki.

          o    Pak (c) 1988-1989 by NoGate Consulting.

          o    Zoo (c) 1988 by Rahul Dhesi.

          o    Arj (c) 1990-1991 by Robert K. Jung.

          o    Hyper (c) 1989-1990 by P. Sawatzki & K.P. Nischke.

          o    DWC (c) 1986-90 by Dean W. Cooper.

          o    GIFLite (c) 1991 by Tsung Hu.

     Latest Known Versions of External Programs are:
      
        Compressed File     Version     Exe File     Explanation
        ---------------     -------   ------------   ----------------------
        SCANV85.ZIP           85          SCAN.EXE   Virus Scan Program by
                                                       McFee
        ZC200.ZIP            2.00           ZC.EXE   Writes Zip Comments
        ARJ220.EXE           2.20          ARJ.EXE   Process *.arj files



     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                     Page 11
     ----------------------------------------------------------------------

        DWC-A510.EXE         5.10          DWC.EXE   Process *.dwc files
        HYPER25.EXE          2.5         HYPER.EXE   Process *.hyp files
        LHA212.EXE           2.12          LHA.EXE   Process *.lzh files
           ?                 1.14          ICE.EXE   Process *.ice files
        PAK251.EXE           2.51          PAK.EXE   Process *.pak & *.sdn
                                                       files
        PK361.EXE            3.61        PKPAK.EXE &
                                       PKUNPAK.EXE   Process *.arc files
        PKZ110.EXE           1.10        PKZIP.EXE &
                                       PKUNZIP.EXE   Process *.zip files
        ZOO201.EXE           2.01          ZOO.EXE   Process *.zoo files
           ?                 1.22      GIFLITE.EXE   Process *.gif files

     Technical Support:

          The author is available to provide technical support if you have
          problems with TRANSCAN.  You may contact Craig Dunstan 24 hours a
          day at THE COMPUTER POST BBS (507) 345-3075.  Or you can send
          Netmail Messages to FIDO 1:14/779.






































     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                     Page 12
     ----------------------------------------------------------------------

                                   APPENDIX A
                        ERROR CODES OF EXTERNAL PROGRAMS

     TranScan monitors the ErrorLevel Code returned by all external
     programs called and records these codes in the TranScan.Log.  The
     following is an explanation of each of the ErrorLevels for each
     external program supported:

     ARJ.EXE (Arj200.exe):
      
         0     Success
         1     Warning (specified file to add to archive not found or
               specified file to list, extract, etc., not found)
         2     Fatal Error
         3     CRC error (header or file CRC error)
         4     ARJ-SECURITY error or attempt to update an ARJ-SECURED
               archive
         5     Disk full or write error
         6     Can't open archive or file
         7     simple user error (bad parameters)
         8     not enough memory
      
     HYPER.EXE (Hyper25.exe):
      
         0     Normal Exit
         1     Nothing to do
         2     Archive Error
         3     Compression Error
         4     Memory Error
         5     CheckSum Error
        14     Disk Full
        98     Error Creating Archive
       101     Input Error
       102     Output Error
       255     Control-C pressed
      
     LHARC (Lh113c.exe):
      
         0     Normally finished.
         1     Process finished with nonexistent file names ignored during
               archiving or CRC error occurred during un-archiving.
         2     Process terminated by fatal error; no archive created or
               files moved.
         3     Unable to write temporary files into the archive.  Work file
               renamed to 'LHARC.)2(' and original archive deleted.  Try
               renaming LHARC.)2) as your archive, although it might be
               damaged.
      
     PAK (Pak210.exe):
      
         0     No Error
         1     CRC error in file or file missing
         2     Out of memory
         7     Disk error



     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                     Page 13
     ----------------------------------------------------------------------

      
     PKPAK & PKUNPAK (Pk361.exe) and PKXARC (Pkxarc.exe):
      
         0     No Error
         1     Bad CRC, file is not an archive, unknown compression method,
               can't create a file, squeeze table is invalid or no files
               found to extract.
         2     Out of memory
         3     No archives found to extract
         4     Can't open archive file
         5     Read error on archive
         6     Internal table overflow
         7     Disk full
      
     PKZIP (Pkz110.exe)
      
         0     No Error
         1     Bad file name or file specification
       2,3     Error in ZIP file
      4-11     Insufficient Memory
        12     No files were found to add to the ZIP file, or no files were
               specified for deletion
        13     File not found
        14     Disk full
        15     ZIP file is read-only and can not be modified
        16     Bad or illegal parameters specified
        17     Too many files
      
     PKUNZIP (Pkz110.exe):
      
         0     No error
         1     Warning error (such as failed CRC check)
       2,3     Error in ZIP file
       4-8     Insufficient Memory
         9     File not found. No ZIP files found.
        10     Bad or illegal parameters specified.
        11     No files found to extract/view etc.
        50     Disk full
        51     Enexpected EOF in ZIP file
      
     SCAN.EXE (Scanv80.zip):
      
         0     No viruses found
         1     One or more viruses found
         2     Abnormal termination (program error)
      
               I do not have the ErrorLevel codes for LHA212.EXE or
               ZOO200.EXE.  If anyone has a list of these for me I will be
               sure to include them in the next revision of these DOCs.








     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                     Page 14
     ----------------------------------------------------------------------

                                   APPENDIX B
                                REVISION HISTORY
      
      

     1.12  8/19/91  First TranScan Release to the Public!

     2.00  9/13/91  Second TranScan Release to the Public!
                    Process Imbeded Compressed Files to any level.
                    Update WC 3.0 Databases with new filename and filesize
                    information.
                    TranSwport the file description, uploader, and password
                    from WC 3.0 Databases to the TranScan.Log.
                    Support for compressing GIF files with GIFLite, even in
                    Imbeded Compressed Files.
                    Minute switch added to instruct TranScan to only
                    process files for so many minutes.

     2.10 10/25/91  Third TranScan Release to the Public!
                    COM support now available for ports 1-8 and bauds up to
                    115,000.
                    NETWORK support now available for ALL Networks
                    supported by Wildcat.  Includes file locking.
                    Command line simplified!
                    Lots of program optimization, some renaming of TranScan
                    support files. 

     2.20 12/29/91  Fourth TranScan Release to the Public!
                    Lots of bug fixes and a number of program enhancements
                    too numerous to relist here. 

     2.21 01/03/92  Fixed problem with Updating all the Wildcat Database
                    Keys. 
























     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED 


     1/3/92                      TRANSCAN v2.21                     Page 15
     ----------------------------------------------------------------------

                                   APPENDIX C
                           BETA TESTERS FOR TRANSCAN

     Special Thanks to the following Beta Testers who have been extreemely
     helpful in testing TranScan:

                              Rick Emmick
                              Mark Tetrault
                              Jerry Arnold
                              Brian Morison
                              Marc Hufnagel
                              Mike Surfer
                              Robert Carlson
                              David Costelloe
                              Les Campbell
                              David Katz
                              Kevin Sonney
                              James Minton
                              Hal Davis
                              Manfred Luft
                              Carl Ricketts
                              William Edsall
                              Michael Crosson
                              Jerry Houston
                              Frank Self
                              Ken Dozotell
                              Chris Williams
                              Dale Crosbie
                              Richard Hoover
                               



























     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED


     1/3/92                      TRANSCAN v2.21                     Page 16
     ----------------------------------------------------------------------

                               REGISTRATION FORM

     If you like what TRANSCAN can do and haven't registered then print
     this registration form out and send it along with $5.00 to:  Craig E.
     Dunstan, 235 Jaycee Ct. #104, Mankato, MN 56001.

     Name:____________________________________________________________

     Address:_________________________________________________________

     City:_____________________ State:_______ Zip:____________________

     HOME Phone No:___________________________________________________

     BBS Name:________________________________________________________

     BBS PHONE NO:____________________________________________________

     Fido Address (if applicable): ___:______/_______

     If you would like to be pre-registered on THE COMPUTER POST please
     provide the following information:

     Name To Use:______________________ Password:_____________________

     Comments:________________________________________________________

     _________________________________________________________________

     _________________________________________________________________

     _________________________________________________________________

     Check-One:

     [ ] Registration for TRANSCAN v2.21..............................$5.00

     [ ] Registration for TRANSCAN v2.21 with COM routines...........$10.00

     [ ] Registration for TRANSCAN v2.21 with COM & NETWORK support..$15.00

                                                                            















     ----------------------------------------------------------------------
         Copyright 1991-1992 by Craig E. Dunstan -- ALL RIGHTS RESERVED